@@ -1,7 +1,7 @@
-<?
+<?php
 /*
  * Gallery - a web based photo album viewer and editor
- * Copyright (C) 2000-2001 Bharat Mediratta
+ * Copyright (C) 2000-2006 Bharat Mediratta
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -15,21 +15,14 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
+ *
+ * $Id: Database.php,v 1.11.2.1 2006/03/27 15:31:26 jenst Exp $
  */
 ?>
-<?
+<?php
 class Abstract_Database {
-	var $tablePrefix;
-
-	function setTablePrefix($prefix) {
-		$this->tablePrefix = $prefix;
-	}
-
-	function prefix($tablename) {
-		return $this->tablePrefix . $tablename;
-	}
-
+    
 	function query($sql) {
 		print "Error: query() should be overridden by a subclass!";
 	}
@@ -38,4 +31,4 @@ class Abstract_Database {
 		print "Error: fetch_row() should be overridden by a subclass!";
 	}
 }
-?>
\ No newline at end of file
+?>
