@@ -1,7 +1,7 @@
-<?
+<?php
 /*
  * Gallery - a web based photo album viewer and editor
- * Copyright (C) 2000-2001 Bharat Mediratta
+ * Copyright (C) 2000-2006 Bharat Mediratta
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -15,10 +15,12 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
+ *
+ * $Id: Database.php,v 1.12.2.1 2006/03/27 15:31:26 jenst Exp $
  */
 ?>
-<?
+<?php
 class MySQL_Database extends Abstract_Database {
 	var $link;
 
@@ -36,4 +38,4 @@ class MySQL_Database extends Abstract_Database {
 		return $row;
 	}
 }
-?>
\ No newline at end of file
+?>
