@@ -1,7 +1,7 @@
-<?
+<?php
 /*
  * Gallery - a web based photo album viewer and editor
- * Copyright (C) 2000-2001 Bharat Mediratta
+ * Copyright (C) 2000-2006 Bharat Mediratta
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -15,16 +15,20 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
+ *
+ * $Id: AdminUser.php,v 1.11.2.1 2006/03/27 15:31:27 jenst Exp $
  */
 ?>
-<?
+<?php
 class Nuke5_AdminUser extends Abstract_User {
 	var $db;
+	var $prefix;
 
 	function Nuke5_AdminUser($admin) {
 		global $gallery;
 		$this->db = $gallery->database{"nuke"};
+		$this->prefix = $gallery->database{"prefix"};
 
 		if(!is_array($admin)) {
 			$admin = base64_decode($admin);
@@ -35,7 +39,7 @@ class Nuke5_AdminUser extends Abstract_User {
 		}
 
 		$results = $this->db->query("select name, email from " .
-				$this->db->prefix("authors") . " " .
+				$this->prefix . "authors " .
 				"where aid='$aid'");
 		$row = $this->db->fetch_row($results);
 		$this->username = $aid;
